@@ -60,12 +60,15 @@ class FhirResource:
             else []
         )
         if len(issues):
-            errors = "\n".join(
-                [
-                    f"* {issue['location'][0]}: {issue['diagnostics']} at {issue['location'][1]}"
-                    if "location" in issue
-                    else f"* {issue['diagnostics']}"
-                    for issue in issues
-                ]
-            )
+            errors = ""
+            for issue in issues:
+                if issue.get("location"):
+                    errors += (
+                        f"* {issue['location'][0]}: {issue['diagnostics']}"
+                        f" at {issue['location'][1]}\n"
+                        if len(issue["location"]) == 2
+                        else "\n"
+                    )
+                else:
+                    errors += f"* {issue['diagnostics']}\n"
             raise FhirValidationError(f"the FHIR server returned a list of issues\n{errors}")
